@@ -3,6 +3,7 @@ import glob
 import inspect
 from os.path import basename, dirname, exists, join, relpath, splitext
 from pathlib import PurePosixPath
+import posixpath
 import pprint
 import subprocess
 import sys
@@ -166,9 +167,16 @@ class ImportCreator:
             parents=[parent_parser],
         )
         parser.add_argument("base", help="Ex: wpiutil")
-        parser.add_argument("compiled", help="Ex: wpiutil._impl.wpiutil")
+        parser.add_argument("compiled", nargs="?", help="Ex: wpiutil._impl.wpiutil")
         return parser
 
+    def _rel(self, base: str, compiled: str) -> str:
+        base = posixpath.join(*base.split("."))
+        compiled = posixpath.join(*compiled.split("."))
+        elems = posixpath.relpath(compiled, base).split("/")
+        elems = ["" if e == ".." else e for e in elems]
+        return f".{'.'.join(elems)}"
+
     def run(self, args):
         # Runtime Dependency Check
         try:
@@ -177,18 +185,22 @@ class ImportCreator:
             print("Error, The following module is required to run this tool: black")
             exit(1)
 
+        compiled = args.compiled
+        if not compiled:
+            compiled = f"{args.base}._{args.base.split('.')[-1]}"
+
         # TODO: could probably generate this from parsed code, but seems hard
         ctx = {}
-        exec(f"from {args.compiled} import *", {}, ctx)
+        exec(f"from {compiled} import *", {}, ctx)
 
-        relimport = "." + ".".join(
-            args.compiled.split(".")[len(args.base.split(".")) :]
-        )
+        relimport = self._rel(args.base, compiled)
+
+        stmt_compiled = "" if not args.compiled else f" {args.compiled}"
 
         stmt = inspect.cleandoc(
             f"""
 
-            # autogenerated by 'robotpy-build create-imports {args.base} {args.compiled}'
+            # autogenerated by 'robotpy-build create-imports {args.base}{stmt_compiled}'
             from {relimport} import {','.join(sorted(ctx.keys()))}
             __all__ = ["{'", "'.join(sorted(ctx.keys()))}"]
         
