@@ -15,10 +15,7 @@ from os.path import (
     splitext,
 )
 import posixpath
-import subprocess
-import sys
 import shutil
-import tempfile
 import toposort
 from typing import Dict, List, Optional, Set
 import yaml
@@ -386,15 +383,12 @@ class Wrapper:
                                 )
 
                 if dl.dlopenlibs:
-                    libnames_full += [
+                    dlopen_libnames_full = [
                         f"{self.platform.libprefix}{lib}{libext}"
                         for lib in dl.dlopenlibs
                     ]
-                    if libext != linkext:
-                        extract_names += [
-                            f"{self.platform.libprefix}{lib}{linkext}"
-                            for lib in dl.dlopenlibs
-                        ]
+                    libnames_full += dlopen_libnames_full
+                    extract_names += dlopen_libnames_full
 
                 to = {
                     posixpath.join(dl.libdir, libname): join(libdir, libname)
